@@ -3,6 +3,7 @@ from copy import deepcopy
 from aiida.orm import load_node
 from aiida.engine.launch import submit
 from hzdplugins.aiidaplugins.constants import results_keys_set, slurm_options
+from aiida.orm.nodes.data.upf import get_pseudos_from_structure
 
 def qePwOriginalSubmit(results, codename, structure, kpoints, pseudo_family, metadata, add_parameters={}, del_parameters={}, cluster_options={}):
 
@@ -300,6 +301,6 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
     results_tmp[str(calc.pk)]['exit_status'] = None
     results_tmp[str(calc.pk)]['is_finished'] = None
     results_tmp[str(calc.pk)]['is_finished_ok'] = None
-    results_tmp[str(calc.pk)]['previous_calc'] = pk # pk is the previous calculation
+    results_tmp[str(calc.pk)]['previous_calc'] = str(pk) # pk is the previous calculation
 
     return results_tmp, calc.pk
